import { EWalletDataType } from "../enum/index.js";
import { HexString32 } from "../primitives/index.js";
export declare const MAX_QUESTIONNAIRES = 64;
/**
 * DataPermissions represent the rules to follow when processing queries for a particular
 * cohort. They are basically auto-reject rules to follow that are baked into the consent
 * token itself in the Token URI.
 */
export declare class DataPermissions {
    protected readonly agreementFlags: HexString32;
    constructor(agreementFlags: HexString32);
    static readonly baseQuestionnaireBit = 128;
    getFlags(): HexString32;
    eq(otherFlags: HexString32): boolean;
    contains(other: DataPermissions): boolean;
    get Age(): boolean;
    get Gender(): boolean;
    get GivenName(): boolean;
    get FamilyName(): boolean;
    get Birthday(): boolean;
    get Email(): boolean;
    get Location(): boolean;
    get SiteVisits(): boolean;
    get EVMTransactions(): boolean;
    get AccountBalances(): boolean;
    get AccountNFTs(): boolean;
    get LatestBlockNumber(): boolean;
    get Discord(): boolean;
    get Twitter(): boolean;
    get AccountSize(): boolean;
    /**
     * Questionnaires are assigned to a set of bits starting at 128. The questionnaireNumber
     * is 0 indexed. If you request a questionnaireNumber that is out of range, this will
     * return false.
     */
    Questionnaire(questionnaireNumber: number): boolean;
    getFlag(flagNumber: number): boolean;
    static get allPermissionsHexString(): HexString32;
    static get permissionString(): HexString32;
    static createWithAllPermissions(): DataPermissions;
    static createWithPermissions(dataTypes: EWalletDataType[]): DataPermissions;
    static getDataTypesFromFlags(agreementFlags: HexString32): EWalletDataType[];
}
//# sourceMappingURL=DataPermissions.d.ts.map